=== modified file 'source/addonHandler.py'
--- source/addonHandler.py	2012-05-13 16:58:15 +0000
+++ source/addonHandler.py	2012-07-02 13:22:37 +0000
@@ -346,7 +346,7 @@
 		""" Constructs an L{AddonBundle} from a filename.
 		@param bundlePath: The path for the bundle file.
 		"""
-		self._path = bundlePath
+		self._path = bundlePath if isinstance(bundlePath, unicode) else unicode(bundlePath, "mbcs")
 		# Read manifest:
 		translatedInput=None
 		with zipfile.ZipFile(self._path, 'r') as z:
@@ -364,8 +364,20 @@
 		@param addonPath: Path where to extract contents.
 		@type addonPath: string
 		"""
+		log.debug("Extracting add-on %s to %s", self._manifest['name'], addonPath)
 		with zipfile.ZipFile(self._path, 'r') as z:
-			z.extractall(addonPath)
+			# As python's zipfile module doesn't handle unicode file names
+			# Manually extract the zipfile contencts with the proper name
+			for entry in z.infolist():
+				# Use cp437 for path decoding (winzip seems to use that acording to python documentation)
+				fsPath = os.path.join(addonPath, unicode(entry.filename, "cp437"))
+				log.debug("Writing file %s", fsPath)
+				dir = os.path.dirname(fsPath)
+				if not os.path.exists(dir):
+					os.makedirs(dir)
+				with z.open(entry) as src:
+					with open(fsPath, 'wb') as dest:
+						shutil.copyfileobj(src, dest)
 
 	@property
 	def manifest(self):

